@@ -3,7 +3,6 @@ from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
 from nerualpha.services.jwt.jwtPayload import JWTPayload
-from nerualpha.providers.logger.ILogAction import ILogAction
 from nerualpha.request.IRequestParams import IRequestParams
 
 
@@ -55,7 +54,7 @@ class IBridge(ABC):
     def getSystemTime(self):
         pass
     @abstractmethod
-    def log(self,logAction):
+    def log(self,data):
         pass
     @abstractmethod
     def getObjectKeys(self,obj):
